pub unsafe fn read_input<'a>(ptr: u32, len: u32) -> &'a [u8] ⓘExpand description
View the host-written input buffer as a byte slice.
Safety
ptr and len must describe a single allocation written by the host
(via alloc) that lives for the duration of the returned borrow.